==> nextcloud-24.0.9.tgz: nextcloud/apps/dav/l10n/el.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Ημερολόγιο",
    "Personal" : "Προσωπικά",
    "{actor} created calendar {calendar}" : "{actor} δημιουργήθηκε το ημερολόγιο {calendar}",
    "You created calendar {calendar}" : "Δημιουργήσατε ημερολόγιο {ημερολόγιο}",
    "{actor} deleted calendar {calendar}" : "{actor} διέγραψε το ημερολόγιο {calendar}",
    "You deleted calendar {calendar}" : "Διαγράψατε το ημερολόγιο {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ενημέρωσε το ημερολόγιο {calendar}",
    "You updated calendar {calendar}" : "Έχετε ενημερώσει το ημερολόγιο {calendar}",
    "You restored calendar {calendar}" : "Επαναφέρατε το ημερολόγιο {calendar}",
    "You shared calendar {calendar} as public link" : "Μοιραστήκατε το ημερολόγιο {calendar} με δημόσιο σύνδεσμο.",
    "You removed public link for calendar {calendar}" : "Αφαιρέσατε τον δημόσιο σύνδεσμο για το ημερολόγιο {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} διαμοιράστηκε το ημερολόγιο {calendar} με εσάς",
    "You shared calendar {calendar} with {user}" : "Διαμοιραστήκατε το ημερολογίου {calendar} με {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} διαμοίρασε το ημερολόγιο {calendar} με {user}",
    "{actor} unshared calendar {calendar} from you" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από εσάς",
    "You unshared calendar {calendar} from {user}" : "Σταματήσατε τον διαμοιρασμό ημερολογίου  {calendar} από {user}",
    "{actor} unshared calendar {calendar} from {user}" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από τον χρήστη {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από τον εαυτό τους",
    "You shared calendar {calendar} with group {group}" : "Διαμοιραστείκατε ένα ημερολόγιο {calendar} με την ομάδα {group}",
    "{actor} shared calendar {calendar} with group {group}" : "Ο {actor} διαμοιράστηκε το ημερολόγιο {calendar} με την ομάδα {group}",
    "You unshared calendar {calendar} from group {group}" : "Σταματήσατε τον διαμοιρασμό του ημερολογίου {calendar} από την ομάδα {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από την ομάδα {group}",
    "Untitled event" : "Συμβάν χωρίς τίτλο",
    "{actor} created event {event} in calendar {calendar}" : "Ο {actor} δημιούργησε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You created event {event} in calendar {calendar}" : "Δημιουργήσατε το γεγονός {event} στο ημερολόγιο {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "Ο {actor} διέγραψε το γεγονός {event} από το ημερολόγιο {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Διαγράψατε το συμβάν {event} από το ημερολόγιο {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "Ο {actor} ενημέρωσε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ενημερώσατε το συμβάν {event} στο ημερολόγιο {calendar}",
    "Busy" : "Απασχολημένος",
    "Calendar, contacts and tasks" : "Ημερολόγιο, επαφές και εργασίες",
    "A <strong>calendar</strong> was modified" : "Τροποποιήθηκε ένα <strong>ημερολόγιο</strong> ",
    "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
    "A calendar <strong>to-do</strong> was modified" : "Τροποποιήθηκε μια <strong>εκκρεμότητα</strong> ημερολογίου",
    "Contact birthdays" : "Γενέθλια επαφών",
    "Death of %s" : "Θάνατος του %s",
    "Calendar:" : "Ημερολόγιο:",
    "Date:" : "Ημερομηνία:",
    "Where:" : "Που:",
    "Description:" : "Περιγραφή:",
    "_%n year_::_%n years_" : ["%n χρόνος/χρονιά","%n χρόνια"],
    "_%n month_::_%n months_" : ["%n μήνας","%d μήνες"],
    "_%n day_::_%n days_" : ["%n ημέρα","%n ημέρες"],
    "_%n hour_::_%n hours_" : ["%nώρα","%nώρες"],
    "_%n minute_::_%n minutes_" : ["%n λεπτό","%n λεπτά"],
    "%s (in %s)" : "%s (σε %s)",
    "%s (%s ago)" : "%s (%s πριν)",
    "Calendar: %s" : "Ημερολόγιο:%s",
    "Date: %s" : "Ημερομηνία:%s",
    "Description: %s" : "Περιγραφή:%s",
    "Where: %s" : "Που:%s",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "Invitation canceled" : "Η πρόσκληση ακυρώθηκε.",
    "Invitation updated" : "Ενημερώθηκε η πρόσκληση.",
    "Invitation" : "Πρόσκληση",
    "Title:" : "Τίτλος:",
    "Time:" : "Ώρα:",
    "Location:" : "Τοποθεσία:",
    "Link:" : "Σύνδεσμος:",
    "Organizer:" : "Διοργανωτής:",
    "Attendees:" : "Συμμετέχοντες:",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "More options …" : "Περισσότερες επιλογές...",
    "More options at %s" : "Περισσότερες επιλογές στο %s",
    "Contacts" : "Επαφές",
    "You created contact {card} in address book {addressbook}" : "Δημιουργήσατε την επαφή {card} στο βιβλίο διευθύνσεων {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Διαγράψατε την επαφή {card} από το βιβλίο διευθύνσεων {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ενημερώσατε την επαφή {card} στο βιβλίο διευθύνσεων {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Τροποποιήθηκε μια <strong>επαφή</strong> ή ένα <strong>βιβλίο διευθύνσεων</strong>",
    "System is in maintenance mode." : "Το σύστημα βρίσκεται σε λειτουργία συντήρησης.",
    "Upgrade needed" : "Απαιτείται αναβάθμιση",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Το %s θα πρέπει να ρυθμιστεί για να χρησιμοποιεί HTTPS  για την χρήση του CalDAV και του CardDAV με το iOS/macOS.",
    "Configures a CalDAV account" : "Ρυθμίσεις λογαριασμού CalDAV",
    "Configures a CardDAV account" : "Ρυθμίσεις λογαριασμού CardDAV",
    "Events" : "Συμβάντα",
    "Tasks" : "Εργασίες",
    "Untitled task" : "Εργασία χωρίς όνομα",
    "Completed on %s" : "Ολοκληρώθηκε %s",
    "Contacts and groups" : "Επαφές και ομάδες",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Τερματικό WebDAV",
    "Availability" : "Διαθεσιμότητα",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Εάν διαμορφώσετε τις ώρες εργασίας σας, οι άλλοι χρήστες θα βλέπουν πότε είστε εκτός γραφείου όταν κάνουν κράτηση για μια συνάντηση.",
    "Time zone:" : "Ζώνη ώρας:",
    "to" : "προς",
    "Delete slot" : "Διαγραφή θέσης",
    "No working hours set" : "Δεν έχει οριστεί ωράριο εργασίας",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sunday" : "Κυριακή",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Ορισμός αυτόματα της κατάστασης χρήστη σε \"Μην ενοχλείτε\" εκτός διαθεσιμότητας για σίγαση όλων των ειδοποιήσεων.",
    "Save" : "Αποθήκευση",
    "Failed to load availability" : "Αποτυχία φόρτωσης της διαθεσιμότητας",
    "Failed to save availability" : "Αποτυχία αποθήκευσης της διαθεσιμότητας",
    "Calendar server" : "Διακομιστής ημερολογίου",
    "Send invitations to attendees" : "Αποστολή προσκλήσεων στους συμμετέχοντες.",
    "Automatically generate a birthday calendar" : "Δημιουργία ημερολογίου γενεθλίων αυτόματα",
    "Birthday calendars will be generated by a background job." : "Τα ημερολόγια γενεθλίων θα δημιουργηθούν από μία εργασία παρασκηνίου.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Ως εκ τούτου, δεν θα είναι διαθέσιμα αμέσως μετά την ενεργοποίηση, αλλά θα εμφανιστούν μετά από λίγη ώρα.",
    "Send notifications for events" : "Αποστολή ειδοποιήσεων για γεγονότα",
    "Notifications are sent via background jobs, so these must occur often enough." : "Οι ειδοποιήσεις αποστέλλονται μέσω εργασιών παρασκηνίου, οπότε πρέπει να εμφανίζονται αρκετά συχνά.",
    "Send reminder notifications to calendar sharees as well" : "Αποστολή ειδοποιήσεων υπενθύμισης και στους κοινούς χρήστες του ημερολογίου",
    "Reminders are always sent to organizers and attendees." : "Οι υπενθυμίσεις αποστέλλονται πάντα στους διοργανωτές και στους συμμετέχοντες.",
    "Enable notifications for events via push" : "Ενεργοποίηση ειδοποιήσεων μέσω push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Εγκαταστήστε επίσης την {calendarappstoreopen}Εφαρμογή ημερολογίου{linkclose}, ή {calendardocopen}συνδέστε τον υπολογιστή & το κινητό σας για συγχρονισμό ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Παρακαλώ σιγουρευτείτε για την σωστή ρύθμιση {emailopen}του διακομιστή αλληλογραφίας{linkclose}.",
    "There was an error updating your attendance status." : "Σφάλμα ενημέρωσης κατάστασής σας.",
    "Please contact the organizer directly." : "Παρακαλώ επικοινωνήστε απ' ευθείας με τον διοργανωτή.",
    "Are you accepting the invitation?" : "Αποδέχεστε την πρόσκληση;",
    "Tentative" : "Δοκιμαστικό",
    "Your attendance was updated successfully." : "Η παρουσία σας ενημερώθηκε με επιτυχία.",
    "Todos" : "Εργασίες προς εκτέλεση",
    "{actor} created todo {todo} in list {calendar}" : "{actor} δημιούργησε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "You created todo {todo} in list {calendar}" : "Δημιουργήσατε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "{actor} deleted todo {todo} from list {calendar}" : "Ο {actor} διέγραψε την εκκρεμότητα  {todo} από τη  λίστα {ημερολόγιο}",
    "You deleted todo {todo} from list {calendar}" : "Διέγραψες την εκκρεμότητα {todo} από τη λίστα {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ενημέρωσε την εκκρεμότητα {todo} στη λίστα {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ενημέρωσες την εκκρεμότητα {todo} στη λίστα {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} επίλυσε την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You solved todo {todo} in list {calendar}" : "Επίλυσες την εκκρεμότητα {todo} στην λίστα {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} άνοιξε ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Άνοιξες ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Ενός ημερολογίου η <strong>εκκρεμότητα</strong> τροποποιήθηκε"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.11.tgz: nextcloud/apps/dav/l10n/el.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Ημερολόγιο",
    "Personal" : "Προσωπικά",
    "{actor} created calendar {calendar}" : "{actor} δημιουργήθηκε το ημερολόγιο {calendar}",
    "You created calendar {calendar}" : "Δημιουργήσατε ημερολόγιο {ημερολόγιο}",
    "{actor} deleted calendar {calendar}" : "{actor} διέγραψε το ημερολόγιο {calendar}",
    "You deleted calendar {calendar}" : "Διαγράψατε το ημερολόγιο {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ενημέρωσε το ημερολόγιο {calendar}",
    "You updated calendar {calendar}" : "Έχετε ενημερώσει το ημερολόγιο {calendar}",
    "You restored calendar {calendar}" : "Επαναφέρατε το ημερολόγιο {calendar}",
    "You shared calendar {calendar} as public link" : "Μοιραστήκατε το ημερολόγιο {calendar} με δημόσιο σύνδεσμο.",
    "You removed public link for calendar {calendar}" : "Αφαιρέσατε τον δημόσιο σύνδεσμο για το ημερολόγιο {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} διαμοιράστηκε το ημερολόγιο {calendar} με εσάς",
    "You shared calendar {calendar} with {user}" : "Διαμοιραστήκατε το ημερολογίου {calendar} με {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} διαμοίρασε το ημερολόγιο {calendar} με {user}",
    "{actor} unshared calendar {calendar} from you" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από εσάς",
    "You unshared calendar {calendar} from {user}" : "Σταματήσατε τον διαμοιρασμό ημερολογίου  {calendar} από {user}",
    "{actor} unshared calendar {calendar} from {user}" : "Ο {actor} σταμάτησε τον διαμοιρασμό του ημερολογίου  {calendar} από τον χρήστη {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από τον εαυτό τους",
    "You shared calendar {calendar} with group {group}" : "Διαμοιραστείκατε ένα ημερολόγιο {calendar} με την ομάδα {group}",
    "{actor} shared calendar {calendar} with group {group}" : "Ο {actor} διαμοιράστηκε το ημερολόγιο {calendar} με την ομάδα {group}",
    "You unshared calendar {calendar} from group {group}" : "Σταματήσατε τον διαμοιρασμό του ημερολογίου {calendar} από την ομάδα {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} σταμάτησε το διαμοιρασμένο ημερολόγιο {calendar} από την ομάδα {group}",
    "Untitled event" : "Συμβάν χωρίς τίτλο",
    "{actor} created event {event} in calendar {calendar}" : "Ο {actor} δημιούργησε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You created event {event} in calendar {calendar}" : "Δημιουργήσατε το γεγονός {event} στο ημερολόγιο {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "Ο {actor} διέγραψε το γεγονός {event} από το ημερολόγιο {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Διαγράψατε το συμβάν {event} από το ημερολόγιο {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "Ο {actor} ενημέρωσε το γεγονός {event} στο ημερολόγιο {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ενημερώσατε το συμβάν {event} στο ημερολόγιο {calendar}",
    "Busy" : "Απασχολημένος",
    "Calendar, contacts and tasks" : "Ημερολόγιο, επαφές και εργασίες",
    "A <strong>calendar</strong> was modified" : "Τροποποιήθηκε ένα <strong>ημερολόγιο</strong> ",
    "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
    "A calendar <strong>to-do</strong> was modified" : "Τροποποιήθηκε μια <strong>εκκρεμότητα</strong> ημερολογίου",
    "Contact birthdays" : "Γενέθλια επαφών",
    "Death of %s" : "Θάνατος του %s",
    "Calendar:" : "Ημερολόγιο:",
    "Date:" : "Ημερομηνία:",
    "Where:" : "Που:",
    "Description:" : "Περιγραφή:",
    "_%n year_::_%n years_" : ["%n χρόνος/χρονιά","%n χρόνια"],
    "_%n month_::_%n months_" : ["%n μήνας","%d μήνες"],
    "_%n day_::_%n days_" : ["%n ημέρα","%n ημέρες"],
    "_%n hour_::_%n hours_" : ["%nώρα","%nώρες"],
    "_%n minute_::_%n minutes_" : ["%n λεπτό","%n λεπτά"],
    "%s (in %s)" : "%s (σε %s)",
    "%s (%s ago)" : "%s (%s πριν)",
    "Calendar: %s" : "Ημερολόγιο:%s",
    "Date: %s" : "Ημερομηνία:%s",
    "Description: %s" : "Περιγραφή:%s",
    "Where: %s" : "Που:%s",
    "%1$s via %2$s" : "%1$s μέσω %2$s",
    "Organizer:" : "Διοργανωτής:",
    "Attendees:" : "Συμμετέχοντες:",
    "Title:" : "Τίτλος:",
    "Time:" : "Ώρα:",
    "Location:" : "Τοποθεσία:",
    "Link:" : "Σύνδεσμος:",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "More options …" : "Περισσότερες επιλογές...",
    "More options at %s" : "Περισσότερες επιλογές στο %s",
    "Contacts" : "Επαφές",
    "You created contact {card} in address book {addressbook}" : "Δημιουργήσατε την επαφή {card} στο βιβλίο διευθύνσεων {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Διαγράψατε την επαφή {card} από το βιβλίο διευθύνσεων {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Ενημερώσατε την επαφή {card} στο βιβλίο διευθύνσεων {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Τροποποιήθηκε μια <strong>επαφή</strong> ή ένα <strong>βιβλίο διευθύνσεων</strong>",
    "System is in maintenance mode." : "Το σύστημα βρίσκεται σε λειτουργία συντήρησης.",
    "Upgrade needed" : "Απαιτείται αναβάθμιση",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Το %s θα πρέπει να ρυθμιστεί για να χρησιμοποιεί HTTPS  για την χρήση του CalDAV και του CardDAV με το iOS/macOS.",
    "Configures a CalDAV account" : "Ρυθμίσεις λογαριασμού CalDAV",
    "Configures a CardDAV account" : "Ρυθμίσεις λογαριασμού CardDAV",
    "Events" : "Συμβάντα",
    "Tasks" : "Εργασίες",
    "Untitled task" : "Εργασία χωρίς όνομα",
    "Completed on %s" : "Ολοκληρώθηκε %s",
    "Contacts and groups" : "Επαφές και ομάδες",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Τερματικό WebDAV",
    "Availability" : "Διαθεσιμότητα",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Εάν διαμορφώσετε τις ώρες εργασίας σας, οι άλλοι χρήστες θα βλέπουν πότε είστε εκτός γραφείου όταν κάνουν κράτηση για μια συνάντηση.",
    "Time zone:" : "Ζώνη ώρας:",
    "to" : "προς",
    "Delete slot" : "Διαγραφή θέσης",
    "No working hours set" : "Δεν έχει οριστεί ωράριο εργασίας",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sunday" : "Κυριακή",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Ορισμός αυτόματα της κατάστασης χρήστη σε \"Μην ενοχλείτε\" εκτός διαθεσιμότητας για σίγαση όλων των ειδοποιήσεων.",
    "Save" : "Αποθήκευση",
    "Failed to load availability" : "Αποτυχία φόρτωσης της διαθεσιμότητας",
    "Failed to save availability" : "Αποτυχία αποθήκευσης της διαθεσιμότητας",
    "Calendar server" : "Διακομιστής ημερολογίου",
    "Send invitations to attendees" : "Αποστολή προσκλήσεων στους συμμετέχοντες.",
    "Automatically generate a birthday calendar" : "Δημιουργία ημερολογίου γενεθλίων αυτόματα",
    "Birthday calendars will be generated by a background job." : "Τα ημερολόγια γενεθλίων θα δημιουργηθούν από μία εργασία παρασκηνίου.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Ως εκ τούτου, δεν θα είναι διαθέσιμα αμέσως μετά την ενεργοποίηση, αλλά θα εμφανιστούν μετά από λίγη ώρα.",
    "Send notifications for events" : "Αποστολή ειδοποιήσεων για γεγονότα",
    "Notifications are sent via background jobs, so these must occur often enough." : "Οι ειδοποιήσεις αποστέλλονται μέσω εργασιών παρασκηνίου, οπότε πρέπει να εμφανίζονται αρκετά συχνά.",
    "Send reminder notifications to calendar sharees as well" : "Αποστολή ειδοποιήσεων υπενθύμισης και στους κοινούς χρήστες του ημερολογίου",
    "Reminders are always sent to organizers and attendees." : "Οι υπενθυμίσεις αποστέλλονται πάντα στους διοργανωτές και στους συμμετέχοντες.",
    "Enable notifications for events via push" : "Ενεργοποίηση ειδοποιήσεων μέσω push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Εγκαταστήστε επίσης την {calendarappstoreopen}Εφαρμογή ημερολογίου{linkclose}, ή {calendardocopen}συνδέστε τον υπολογιστή & το κινητό σας για συγχρονισμό ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Παρακαλώ σιγουρευτείτε για την σωστή ρύθμιση {emailopen}του διακομιστή αλληλογραφίας{linkclose}.",
    "There was an error updating your attendance status." : "Σφάλμα ενημέρωσης κατάστασής σας.",
    "Please contact the organizer directly." : "Παρακαλώ επικοινωνήστε απ' ευθείας με τον διοργανωτή.",
    "Are you accepting the invitation?" : "Αποδέχεστε την πρόσκληση;",
    "Tentative" : "Δοκιμαστικό",
    "Your attendance was updated successfully." : "Η παρουσία σας ενημερώθηκε με επιτυχία.",
    "Todos" : "Εργασίες προς εκτέλεση",
    "{actor} created todo {todo} in list {calendar}" : "{actor} δημιούργησε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "You created todo {todo} in list {calendar}" : "Δημιουργήσατε την εκκρεμότητα {todo} στη λίστα {ημερολόγιο}",
    "{actor} deleted todo {todo} from list {calendar}" : "Ο {actor} διέγραψε την εκκρεμότητα  {todo} από τη  λίστα {ημερολόγιο}",
    "You deleted todo {todo} from list {calendar}" : "Διέγραψες την εκκρεμότητα {todo} από τη λίστα {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ενημέρωσε την εκκρεμότητα {todo} στη λίστα {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ενημέρωσες την εκκρεμότητα {todo} στη λίστα {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} επίλυσε την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You solved todo {todo} in list {calendar}" : "Επίλυσες την εκκρεμότητα {todo} στην λίστα {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} άνοιξε ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Άνοιξες ξανά την εκκρεμότητα {todo} στην λίστα {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Ενός ημερολογίου η <strong>εκκρεμότητα</strong> τροποποιήθηκε",
    "Invitation canceled" : "Η πρόσκληση ακυρώθηκε.",
    "Invitation updated" : "Ενημερώθηκε η πρόσκληση.",
    "Invitation" : "Πρόσκληση"
},
"nplurals=2; plural=(n != 1);");
